@@ -19,40 +19,12 @@ from Classes.shared_scripts.modules import *
 
 # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
 def filestructure():
-    sizechecker("/tmp/fruits")
-   
-
-   
-
-    FILETOWORK = "/tmp/services"
-    try:
-        sizechecker(FILETOWORK)
-    except FileNotFoundError:
-        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
-
-
-    FILETOWORK="/tmp/top10"
-    try:
-        linechecker(FILETOWORK)
-    except FileNotFoundError:
-        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
-
-
-    FILETOWORK="/tmp/bottom10"
-    try:
-        linechecker(FILETOWORK)
-    except FileNotFoundError:
-        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
-    time.sleep(0.5)
-
-
-    FILETOWORK="/tmp/sorted_fruits"
-    try:        
-        sizechecker(FILETOWORK)
-        filechecker(FILETOWORK)
-    except FileNotFoundError:
-        print(bcolors.FAIL +  FILETOWORK + " is not created"+ bcolors.ENDC)
-    time.sleep(0.5)
+    filechecker("/tmp/fruits")
+    sizechecker("/tmp/services")
+    linechecker("/tmp/top10")
+    linechecker("/tmp/bottom10")
+    sizechecker("/tmp/sorted_fruits")
+    filechecker("/tmp/sorted_fruits")
 
 
     FILETOWORK="/tmp/counted_services"
@@ -76,3 +48,4 @@ def filestructure():
  # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # # 
  
 
+filestructure()
\ No newline at end of file
